@@ -103,6 +103,8 @@ show_split_networks_v4 (struct if_info *ifi, u_int32_t splitmask, int v4args, st
 	struct if_info ifi_tmp;
 	int v4args_tmp;
 
+	v4args_tmp = 0;
+
 	if ((v4args & V4VERBSPLIT) == V4VERBSPLIT)
 		printf ("[Split network - verbose]\n");
 	else
@@ -136,7 +138,7 @@ show_split_networks_v4 (struct if_info *ifi, u_int32_t splitmask, int v4args, st
 			bzero ((char *) ifi_tmp.p_v4addr, 19);
 			bzero ((char *) ifi_tmp.p_v4nmask, 16);
 			bzero ((char *) ifi_tmp.p_v6addr, 44);
-			snprintf (ifi_tmp.p_v4addr, 19, "%s", numtoquad (start), splitmask);
+			snprintf (ifi_tmp.p_v4addr, 19, "%s", numtoquad (start));
 			snprintf (ifi_tmp.p_v4nmask, 16, numtoquad (splitmask));
 		}
 		start += diff;
@@ -586,6 +588,8 @@ show_split_networks_v6 (struct if_info *ifi, struct sip_in6_addr splitmask, int
 	struct if_info ifi_tmp;
 	int v6args_tmp;
 
+	v6args_tmp = 0;
+
 	if ((v6args & V6VERBSPLIT) == V6VERBSPLIT)
 		printf ("[Split network - verbose]\n");
 	else
