@@ -61,6 +61,8 @@ out_cmdline (struct if_info *ifarg_cur, int v4args, struct misc_args m_argv4,
 {
 	int ret;
 
+	ret = 0;
+
 	if (ifarg_cur->type == IFT_V4) {
 		printf ("-[ipv4 : %s] - %d\n", ifarg_cur->cmdstr, index);
 		ret = get_addrv4 (ifarg_cur);
@@ -190,7 +192,7 @@ int
 get_stdin (char *args[])
 {
 	char buf[2], sbuf[128], dbuf[128], *arg1, *arg2;
-	int x, y, z, n, argmax;
+	int x, y, z, argmax;
 
 	bzero ((char *) buf, 2);
 
@@ -302,7 +304,7 @@ struct argbox *
 get_boxargs (int argc, char *argv[], int argcount, struct argbox *abox_cur)
 {
 	char expaddr[128];
-	int x, y, z;
+	int x, y;
 	int error;
 
 	error = 0;
@@ -422,7 +424,7 @@ parse_abox (struct argbox *abox, struct if_info *if_start)
 	char *tmpstr;
 	int x, if_found;
 
-	ifarg_cur = ifarg_start =
+	ifarg_old = ifarg_cur = ifarg_start =
 	    (struct if_info *) malloc (sizeof (struct if_info));
 	ifarg_cur->next = NULL;
 	bzero ((char *) ifarg_cur->name, IFNAMSIZ);
@@ -665,13 +667,12 @@ parse_abox (struct argbox *abox, struct if_info *if_start)
 int
 main (int argc, char *argv[])
 {
-	int x, y, z, m, v4args, v6args, error, iffound, argcount, first_err;
+	int x, y, z, m, v4args, v6args, iffound, argcount, first_err;
 	struct if_info *if_start, *if_cur;
 	struct if_info *ifarg_start, *ifarg_cur, *ifarg_old;
 	int ch, parse_stdin, index;
 	struct misc_args m_argv4, m_argv6;
 	int split_errv4, split_errv6;
-	char *tmpstr;
 	char expaddr[128];
 	char oldcmdstr[128];
 	struct argbox *abox_start, *abox_cur, *abox_tmp;
@@ -715,6 +716,7 @@ main (int argc, char *argv[])
 	split_errv4 = 0;
 	split_errv6 = 0;
 	first_err = 1;
+	ifarg_start = NULL;
 	ifarg_old = NULL;
 	resolve = 0;
 
